.. include:: includes.rst

For Loop Rules
--------------

for_loop_001
############

This rule has been moved to **iteration_scheme_301**.

for_loop_002
############

This rule has been moved to **loop_statement_302**.

for_loop_003
############

This rule has been moved to **loop_statement_503**.

for_loop_004
############

This rule has been moved to **loop_statement_103**.

for_loop_005
############

This rule has been moved to **loop_statement_104**.
